# This file is part of discord-shared-db
#
# Copyright (C) 2026 CouchComfy
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.

"""Authentication provider enumeration.

Defines the supported third-party authentication providers for user
accounts in the system.
"""

from enum import Enum

class AuthProviders(Enum):
    """Enumeration of supported authentication providers.
    
    Attributes:
        DISCORD: Discord OAuth provider.
        STEAM: Steam authentication provider.
    """
    DISCORD = 'discord'
    STEAM = 'steam'